@@ -6,13 +6,13 @@
 
 #include "journalsfetchjob.h"
 
-#include <AkonadiCore/CollectionColorAttribute>
-#include <AkonadiCore/EntityDisplayAttribute>
+#include <Akonadi/CollectionColorAttribute>
+#include <Akonadi/EntityDisplayAttribute>
 #include <KCalendarCore/Event>
 #include <KCalendarCore/Todo>
+#include <KContacts/Addressee>
+#include <KContacts/ContactGroup>
 #include <QtConcurrent>
-#include <kcontacts/addressee.h>
-#include <kcontacts/contactgroup.h>
 
 #include "etesync_debug.h"
 
